import { Card } from "./deck.interface";
export default class Deck {
    private deck;
    private drawCards;
    constructor(deck?: Card[]);
    /**
     * Retrieves the deck of cards.
     * @returns {Card[]} The deck of cards.
     */
    getDeck(): Card[];
    /**
     * Initializes the deck with a standard set of playing cards.
     * @returns The current instance of the Deck class.
     */
    initDeck(): this;
    /**
     * Shuffles the deck by swapping random cards multiple times.
     * @param nbShuffleTime The number of times to shuffle the deck. Default is 1000.
     * @returns The updated Deck instance with the shuffled deck.
     */
    shuffleDeck(nbShuffleTime?: number): this;
    /**
     * Draws a card from the deck and adds it to the drawCards array.
     * @returns The card that was drawn from the deck, or undefined if the deck is empty.
     */
    drawCard(): Card | undefined;
}
